@@ -1,15 +1,16 @@
 # -*- coding: utf-8 -*-
 #
 # This code is copied from mvasilkov's django-google-charts on github
-# (https://github.com/mvasilkov/django-google-charts) and licensed under 
+# (https://github.com/mvasilkov/django-google-charts) and licensed under
 # the MIT License
 #
 
 from django.conf import settings
 from django import template
 from django.template.loader import render_to_string
-from django.template.base import TemplateSyntaxError
+from django.template.base import TemplateSyntaxError, VariableDoesNotExist
 from django.core.exceptions import ImproperlyConfigured
+from django.utils.encoding import smart_unicode
 
 register = template.Library()
 
@@ -23,13 +24,14 @@ for pkg in _packages:
         raise ImproperlyConfigured("%s is not a valid package. Valid packages are %s" \
                                    % (pkg, ", ".join(GOOGLECHARTS_PACKAGES)))
 
+
 def _remove_quotes(s):
     if s[0] in ('"', "'") and s[-1] == s[0]:
         return s[1:-1]
     return s
 
-# {% gcharts %} ... {% endgcharts %}
 
+# {% gcharts %} ... {% endgcharts %}
 class GChartsNode(template.Node):
     def __init__(self, nodelist):
         self._nodelist = nodelist
@@ -48,6 +50,7 @@ class GChartsNode(template.Node):
         return self.render_template("gcharts/gcharts.html", googlecharts_js=js,
                                     api=_api, packages=packages)
 
+
 @register.tag
 def gcharts(parser, token):
     nodelist = parser.parse(["endgcharts"])
@@ -56,7 +59,6 @@ def gcharts(parser, token):
 
 
 # {% options "name" %}...{% endoptions %}
-
 class OptionsNode(template.Node):
     def __init__(self, nodelist, name):
         self._nodelist = nodelist
@@ -70,6 +72,7 @@ class OptionsNode(template.Node):
         '''
         return self.render.__doc__ % {'name': self._name, 'data': self._nodelist.render(context)}
 
+
 @register.tag
 def options(parser, token):
     try:
@@ -83,10 +86,9 @@ def options(parser, token):
 
 
 # {% render "container_id" "data" "options" %}
-
 class RenderNode(template.Node):
     def __init__(self, container, data, options, pkg):
-        self.container = container
+        self.container = template.Variable(container)
         self.data = template.Variable(data)
         self.options = options
         self.pkg = pkg
@@ -108,9 +110,15 @@ class RenderNode(template.Node):
             else:
                 raise TemplateSyntaxError("%s is not a valid package. Valid packages are %s" \
                                           % (self.pkg, ", ".join(GOOGLECHARTS_PACKAGES)))
+        try:
+            # Try to resolve the container from context variables.
+            # Useful if creating charts in a loop, etc.
+            container = self.container.resolve(context)
+        except VariableDoesNotExist:
+            container = self.container
+        return self.render.__doc__ % {"options": self.options, "container": container,
+                                      "src": self.data.var, "data": smart_unicode(self.data.resolve(context))}
 
-        return self.render.__doc__ % {"options": self.options, "container": self.container,
-                                      "src": self.data.var, "data": self.data.resolve(context)}
 
 @register.tag
 def render(parser, token):
@@ -121,5 +129,3 @@ def render(parser, token):
         args.append("default")
     _, container, data, options, pkg = [_remove_quotes(s) for s in args]
     return RenderNode(container=container, data=data, options=options, pkg=pkg)
-
-
